@@ -291,13 +291,8 @@ class XItem(XEntity):
         # Post the item:
         response = client.post("Item", item.to_xml())
 
-        # Iterate over the accounts:
-        xitem = XItem()
-        xitem.Code = response["Response"]["Items"]["Item"]["Code"]
-        xitem.Description = response["Response"]["Items"]["Item"]["Description"]
-
         # Done, return the xitem:
-        return xitem
+        return response["Response"]
 
 class XContact(XEntity):
     """
@@ -318,6 +313,20 @@ class XContact(XEntity):
         """
         self.Status = status
 
+    def get_contact_id(self):
+        """
+        Returns the contact id.
+        """
+        return self.get("ContactID")
+
+    def set_contact_id(self, contact_id):
+        """
+        Sets the contact id.
+        """
+        self["ContactID"] = contact_id
+
+    ContactID = property(get_contact_id, set_contact_id)
+
     def get_contact_number(self):
         """
         Returns the contact number.
@@ -506,6 +515,13 @@ class XContact(XEntity):
 
     Phones = property(get_phones, set_phones)
 
+    def to_xml(self):
+        """
+        Provides a json representation of the contact.
+        """
+        return xml2json.json2xml(simplejson.dumps({"Contact": self}))
+
+
 class XInvoice(XEntity):
     """
     Provides an invoice class which is compatible with XERO API.
@@ -567,12 +583,9 @@ class XInvoice(XEntity):
         Sets the type.
         """
         if ctype in self.__class__.InvoiceType.get_all_types():
-            if ctype == self.__class__.InvoiceType.ACCPAY:
-                message = "Accounts payable invoices are not yet implemented"
-                raise NotImplementedError(message)
             self["Type"] = ctype
         else:
-            raise ValueError("Type is unknown: %s" % ctype)
+            raise ValueError("Unknown invoice type: %s" % ctype)
 
     Type = property(get_type, set_type)
 
